const URL = process.env.NODE_ENV === "production" ? "https://api.licenseapi.de" : "/api";

export const request = async (url, method, body, headers) => {
    const response = await fetch(URL + url, {
        method: method,
        headers: {...headers, "Content-Type": "application/json"},
        body: JSON.stringify(body)
    });

    if (response.status === 401) throw new Error("Unauthorized");

    const data = await response.json();

    if (data.code >= 300) throw new Error(data.message);

    if (!response.ok) throw new Error(await response.text());

    return data;
}

export const sessionRequest = (url, method, token, body) => {
    return request(url, method, body, {"Authorization": `Bearer ${token}`});
}